# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from ..passage import Passage

__all__ = ["PassageCreateResponse"]

PassageCreateResponse: TypeAlias = List[Passage]
