# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .tool_search_result import ToolSearchResult

__all__ = ["ToolSearchResponse"]

ToolSearchResponse: TypeAlias = List[ToolSearchResult]
